

namespace EsbDecimals
{
#if (DEBUG)

	public class IntOps
#else
	/// <summary>
	/// Integer Routines for <see cref="EsbDecimals"/> v2.1.0 - 10 June 2011.
	/// </summary>
	public static class IntOps
#endif
	{
		#region Odd Methods

		/// <summary>
		/// Determines whether an Integral value is Odd.
		/// </summary>
		/// <param name="X">Value to Test.</param>
		/// <returns>True if Odd, False if Even.</returns>
		public static bool Odd (int X)
		{
			return ((X % 2 == 1) || (X % 2 == -1));
		}

		/// <summary>
		/// Determines whether an Integral value is Odd.
		/// </summary>
		/// <param name="X">Value to Test.</param>
		/// <returns>True if Odd, False if Even.</returns>
		public static bool Odd (long X)
		{
			return ((X % 2 == 1) || (X % 2 == -1));
		}

		#endregion //Odd Methods

		#region Floor Methods

		/// <summary>
		/// <para>Returns the Integer Value that is less than or equal to the specified number.</para>
		/// <para>For "larger" values <see cref="Floor64(decimal)"/></para>
		/// </summary>
		/// <param name="X">Value to be processed</param>
		/// <returns>Integer Value that is less than or equal to the specified number.</returns>
		public static int Floor (double X)
		{
			return (int) System.Math.Floor (X);
		}

		/// <summary>
		/// <para>Returns the Integer Value that is less than or equal to the specified number.</para>
		/// <para>For "larger" values <see cref="Floor64(decimal)"/></para>
		/// </summary>
		/// <param name="X">Value to be processed</param>
		/// <returns>Integer Value that is less than or equal to the specified number.</returns>
		public static int Floor (decimal X)
		{
			return (int) System.Decimal.Floor (X);
		}

		/// <summary>
		/// Returns the Integer Value that is less than or equal to the specified number.
		/// </summary>
		/// <param name="X">Value to be processed</param>
		/// <returns>Integer Value that is less than or equal to the specified number.</returns>
		public static long Floor64 (double X)
		{
			return (long) System.Math.Floor (X);
		}

		/// <summary>
		/// Returns the Integer Value that is less than or equal to the specified number.
		/// </summary>
		/// <param name="X">Value to be processed</param>
		/// <returns>Integer Value that is less than or equal to the specified number.</returns>
		public static long Floor64 (decimal X)
		{
			return (long) System.Decimal.Floor (X);
		}

		#endregion //Floor Methods

		#region Ceiling Methods

		/// <summary>
		/// <para>Returns the Integer Value that is greater than or equal to the specified number.</para>
		/// <para>For "larger" values <see cref="Ceiling64(decimal)"/></para>
		/// </summary>
		/// <param name="X">Value to be processed</param>
		/// <returns>Integer Value that is greater than or equal to the specified number.</returns>
		public static int Ceiling (double X)
		{
			return (int) System.Math.Ceiling (X);
		}

		/// <summary>
		/// <para>Returns the Integer Value that is greater than or equal to the specified number.</para>
		/// <para>For "larger" values <see cref="Ceiling64(decimal)"/></para>
		/// </summary>
		/// <param name="X">Value to be processed</param>
		/// <returns>Integer Value that is greater than or equal to the specified number.</returns>
		public static int Ceiling (decimal X)
		{
			return (int) DecimalOps.Ceiling (X);
		}

		/// <summary>
		/// Returns the Integer Value that is greater than or equal to the specified number.
		/// </summary>
		/// <param name="X">Value to be processed</param>
		/// <returns>Integer Value that is greater than or equal to the specified number.</returns>
		public static long Ceiling64 (double X)
		{
			return (long) System.Math.Ceiling (X);
		}

		/// <summary>
		/// Returns the Integer Value that is greater than or equal to the specified number.
		/// </summary>
		/// <param name="X">Value to be processed</param>
		/// <returns>Integer Value that is greater than or equal to the specified number.</returns>
		public static long Ceiling64 (decimal X)
		{
			return (long) DecimalOps.Ceiling (X);
		}

		#endregion //Ceiling Methods

		#region IntPart Methods

		/// <summary>
		/// Returns the Integral portion of the value supplied.
		/// </summary>
		/// <param name="X">Number to be processed.</param>
		/// <returns>Integral portion of the value supplied</returns>
		public static int IntPart (double X)
		{
			if (X >= 0)
			{
				return Floor (X);
			}
			return Ceiling (X);
		}

		/// <summary>
		/// Returns the Integral portion of the value supplied.
		/// </summary>
		/// <param name="X">Number to be processed.</param>
		/// <returns>Integral portion of the value supplied</returns>
		public static int IntPart (decimal X)
		{
			if (X >= 0)
			{
				return Floor (X);
			}
			return Ceiling (X);
		}

		/// <summary>
		/// Returns the Integral portion of the value supplied.
		/// </summary>
		/// <param name="X">Number to be processed.</param>
		/// <returns>Integral portion of the value supplied</returns>
		public static long IntPart64 (double X)
		{
			if (X >= 0)
			{
				return Floor64 (X);
			}
			return Ceiling64 (X);
		}

		/// <summary>
		/// Returns the Integral portion of the value supplied.
		/// </summary>
		/// <param name="X">Number to be processed.</param>
		/// <returns>Integral portion of the value supplied</returns>
		public static long IntPart64 (decimal X)
		{
			if (X >= 0)
			{
				return Floor64 (X);
			}
			return Ceiling64 (X);
		}
	}
	#endregion //IntPart Methods

}
